'\" Copyright 1989 Regents of the University of California
'\" Permission to use, copy, modify, and distribute this
'\" documentation for any purpose and without fee is hereby
'\" granted, provided that this notice appears in all copies.
'\" The University of California makes no representations about
'\" the suitability of this material for any purpose.  It is
'\" provided "as is" without express or implied warranty.
'\" 
'\" $Header: /sprite/src/lib/tcl/RCS/Tcl_Backslash.man,v 1.4 89/05/18 16:29:01 ouster Exp $ SPRITE (Berkeley)
'\" 
.\"vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
.\" These macros make this man page compatible with the standard manual files.
.\" They are replacement for the standard sprite macros, the results are not
.\" as beautiful, but they work with standard nroff.
.\"
.\" .HS name section [date [version]]
.\"	Replacement for .TH in other man pages.
.\"
.\" .LG
.\"	Increase font size;  opposite of .SM
.\"
.\" .AP type name in/out [indent]
.\"	Start paragraph describing an argument to a library procedure.
.\"	type is type of argument (int, etc.), in/out is either "in", "out",
.\"	or "in/out" to describe whether procedure reads or modifies arg,
.\"	and indent is equivalent to second arg of .IP (shouldn't ever be
.\"	needed;  use .AS below instead)
.\"
.\" .AS [type [name]]
.\"	Give maximum sizes of arguments for setting tab stops.  Type and
.\"	name are examples of largest possible arguments that will be passed
.\"	to .AP later.  If args are omitted, default tab stops are used.
.\"
'@header
'	# Heading for Sprite man pages
.de HS
.TH "\\$1" "TCL"
..
'	# Increase point size 1 tick
.de LG
.ps +1
.it 1 }N
.if !"\\$1"" \&\\$1 \\$2 \\$3 \\$4 \\$5 \\$6
..
'	# Start an argument description
.de AP
.ie !"\\$4"" .TP \\$4
.el \{\
.   ie !"\\$2"" .TP \\n()Cu
.   el          .TP 15
.\}
.ie !"\\$3"" \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !"\\$2"" \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
.DT
..
'	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !"\\$1"" .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !"\\$2"" .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
'	# BS - start boxed text
.de BS
' no-op
..
'	# BE - end boxed text (draw box now)
.de BE
' no-op
..
'	# VS - start vertical sidebar
.de VS
' no-op
..
'	# VE - end of vertical sidebar
.de VE
' no-op
..
'       # DS - start somekind of indentation
.de DS
.sp
.nf
'       # DE - end somekind of indentation
..
.de DE
.sp
.fi
..
'@endheader
.\"^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.HS Tcl_Backslash tcl
.BS
.SH NAME
Tcl_Backslash \- parse a backslash sequence
.SH SYNOPSIS
.nf
\fB#include <tcl.h>\fR
.sp
char
\fBTcl_Backslash\fR(\fIsrc, countPtr\fR)
.SH ARGUMENTS
.AS int *countPtr
.AP char *src in
Pointer to a string starting with a backslash.
.AP int *countPtr out
If \fIcountPtr\fR isn't NULL, \fI*countPtr\fR gets filled
in with number of characters in the backslash sequence, including
the backslash character.
.BE

.SH DESCRIPTION
.PP
This is a utility procedure used by several of the Tcl
commands.  It parses a backslash sequence and returns
the single character corresponding to the sequence.
\fBTcl_Backslash\fR modifies \fI*countPtr\fR to contain the number of characters in
the backslash sequence.  If \fIsrc\fR doesn't point to a backslash
sequence understood by Tcl, then Tcl_Backslash returns a backslash
as its result and \fI*countPtr\fR gets set to 1 (in this case the
backslash character should not get any special treatment).
.PP
See the Tcl manual entry for information on the valid
backslash sequences.  All of the sequences described in the Tcl
.VS
manual entry are supported by \fBTcl_Backslash\fR except
backslash-newline, which is not understood.
.VE

.SH KEYWORDS
backslash, parse
