'\" Copyright 1989 Regents of the University of California
'\" Permission to use, copy, modify, and distribute this
'\" documentation for any purpose and without fee is hereby
'\" granted, provided that this notice appears in all copies.
'\" The University of California makes no representations about
'\" the suitability of this material for any purpose.  It is
'\" provided "as is" without express or implied warranty.
'\" 
'\" $Header: /sprite/src/lib/tcl/RCS/Tcl_GetVar.man,v 1.3 90/03/11 17:22:41 ouster Exp $ SPRITE (Berkeley)
'\" 
.\"vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
.\" These macros make this man page compatible with the standard manual files.
.\" They are replacement for the standard sprite macros, the results are not
.\" as beautiful, but they work with standard nroff.
.\"
.\" .HS name section [date [version]]
.\"	Replacement for .TH in other man pages.
.\"
.\" .LG
.\"	Increase font size;  opposite of .SM
.\"
.\" .AP type name in/out [indent]
.\"	Start paragraph describing an argument to a library procedure.
.\"	type is type of argument (int, etc.), in/out is either "in", "out",
.\"	or "in/out" to describe whether procedure reads or modifies arg,
.\"	and indent is equivalent to second arg of .IP (shouldn't ever be
.\"	needed;  use .AS below instead)
.\"
.\" .AS [type [name]]
.\"	Give maximum sizes of arguments for setting tab stops.  Type and
.\"	name are examples of largest possible arguments that will be passed
.\"	to .AP later.  If args are omitted, default tab stops are used.
.\"
'@header
'	# Heading for Sprite man pages
.de HS
.TH "\\$1" "TCL"
..
'	# Increase point size 1 tick
.de LG
.ps +1
.it 1 }N
.if !"\\$1"" \&\\$1 \\$2 \\$3 \\$4 \\$5 \\$6
..
'	# Start an argument description
.de AP
.ie !"\\$4"" .TP \\$4
.el \{\
.   ie !"\\$2"" .TP \\n()Cu
.   el          .TP 15
.\}
.ie !"\\$3"" \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !"\\$2"" \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
.DT
..
'	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !"\\$1"" .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !"\\$2"" .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
'	# BS - start boxed text
.de BS
' no-op
..
'	# BE - end boxed text (draw box now)
.de BE
' no-op
..
'	# VS - start vertical sidebar
.de VS
' no-op
..
'	# VE - end of vertical sidebar
.de VE
' no-op
..
'       # DS - start somekind of indentation
.de DS
.sp
.nf
'       # DE - end somekind of indentation
..
.de DE
.sp
.fi
..
'@endheader
.\"^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.HS Tcl_GetVar tcl
.BS
.SH NAME
Tcl_GetVar \- return the value of a Tcl variable
.SH SYNOPSIS
.nf
\fB#include <tcl.h>\fR
.sp
char *
\fBTcl_GetVar\fR(\fIinterp, varName, global\fR)
.SH ARGUMENTS
.AS Tcl_Interp *interp
.AP Tcl_Interp *interp in
Interpreter in which to check for variable.
.AP char *varName in
Name of desired variable.
.AP int global in
If non-zero, then insist that \fIvarName\fR be interpreted as
a global variable regardless of whether a procedure invocation
is in progress.
.BE

.SH DESCRIPTION
.PP
\fBTcl_GetVar\fR is a utility procedure used by several of the Tcl commands.
It returns the value of variable \fIvarName\fR in
interpreter \fIinterp\fR.  If there isn't a Tcl command procedure
being interpreted right now, or if \fIglobal\fR is non-zero,
then \fIvarName\fR is always treated
as the name of a global variable.  Otherwise, if a procedure is
being interpreted,
then \fIvarName\fR will be treated as a local variable name, unless
it has been declared global using the \fBglobal\fR command.  If
no variable by the name \fIvarName\fR exists right now, then a NULL
pointer is returned.

.SH KEYWORDS
interpreter, global, local, variable
