'\" Copyright 1989 Regents of the University of California
'\" Permission to use, copy, modify, and distribute this
'\" documentation for any purpose and without fee is hereby
'\" granted, provided that this notice appears in all copies.
'\" The University of California makes no representations about
'\" the suitability of this material for any purpose.  It is
'\" provided "as is" without express or implied warranty.
'\" 
'\" $Header: /sprite/src/lib/tcl/RCS/Tcl_Return.man,v 1.3 89/08/16 08:52:46 ouster Exp $ SPRITE (Berkeley)
'\" 
.\"vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
.\" These macros make this man page compatible with the standard manual files.
.\" They are replacement for the standard sprite macros, the results are not
.\" as beautiful, but they work with standard nroff.
.\"
.\" .HS name section [date [version]]
.\"	Replacement for .TH in other man pages.
.\"
.\" .LG
.\"	Increase font size;  opposite of .SM
.\"
.\" .AP type name in/out [indent]
.\"	Start paragraph describing an argument to a library procedure.
.\"	type is type of argument (int, etc.), in/out is either "in", "out",
.\"	or "in/out" to describe whether procedure reads or modifies arg,
.\"	and indent is equivalent to second arg of .IP (shouldn't ever be
.\"	needed;  use .AS below instead)
.\"
.\" .AS [type [name]]
.\"	Give maximum sizes of arguments for setting tab stops.  Type and
.\"	name are examples of largest possible arguments that will be passed
.\"	to .AP later.  If args are omitted, default tab stops are used.
.\"
'@header
'	# Heading for Sprite man pages
.de HS
.TH "\\$1" "TCL"
..
'	# Increase point size 1 tick
.de LG
.ps +1
.it 1 }N
.if !"\\$1"" \&\\$1 \\$2 \\$3 \\$4 \\$5 \\$6
..
'	# Start an argument description
.de AP
.ie !"\\$4"" .TP \\$4
.el \{\
.   ie !"\\$2"" .TP \\n()Cu
.   el          .TP 15
.\}
.ie !"\\$3"" \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !"\\$2"" \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
.DT
..
'	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !"\\$1"" .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !"\\$2"" .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
'	# BS - start boxed text
.de BS
' no-op
..
'	# BE - end boxed text (draw box now)
.de BE
' no-op
..
'	# VS - start vertical sidebar
.de VS
' no-op
..
'	# VE - end of vertical sidebar
.de VE
' no-op
..
'       # DS - start somekind of indentation
.de DS
.sp
.nf
'       # DE - end somekind of indentation
..
.de DE
.sp
.fi
..
'@endheader
.\"^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.HS Tcl_Return tcl
.BS
.SH NAME
Tcl_Return \- set up a Tcl result string
.SH SYNOPSIS
.nf
\fB#include <tcl.h>\fR
.sp
\fBTcl_Return\fR(\fIinterp, string, status\fR)
.SH ARGUMENTS
.AP Tcl_Interp *interp out
Interpreter for which a return value is to be established.
.AP char *string in
String value to be returned, or \fBNULL\fR.
.AP int status in
Indicates the nature of \fIstring\fR.  Must be either \fBTCL_STATIC\fR,
\fBTCL_DYNAMIC\fR, or \fBTCL_VOLATILE\fR.
.BE

.SH DESCRIPTION
.PP
\fBTcl_Return\fR is a convenience routine used by several of the Tcl commands.  It
arranges for \fIstring\fR to be the return string for the current Tcl
command in \fIinterp\fR.  If \fIstatus\fR is \fBTCL_STATIC\fR it means that
\fIstring\fR
refers to an area of static storage that is guaranteed to remain
untouched until at least the next call to \fBTcl_Eval\fR.  If \fIstatus\fR
is \fBTCL_DYNAMIC\fR it means that \fIstring\fR was allocated with a call
to \fBckalloc()\fR and is now the property of the Tcl system.  \fBTcl_Return\fR
will arrange for the string's storage to be released by calling
\fBckfree()\fR when it is no longer needed.  The third possibility is for
\fIstatus\fR to be \fBTCL_VOLATILE\fR.  This means that \fIstring\fR points
to an area of memory that is likely to be overwritten when \fBTcl_Return\fR
returns.  In this case \fBTcl_Return\fR makes a copy of the string and arranges
for the copy to be the return string for the current Tcl command.
.PP
If \fIstring\fR is \fBNULL\fR, then \fIstatus\fR is ignored and \fBTcl_Return\fR
re-initializes \fIinterp\fR's result to point to the pre-allocated result
area, with an empty string in the result area.
.PP
In any of the above cases, if \fIinterp\fR holds a dynamically-allocated
result at the time of the \fBTcl_Return\fR call, the old result's storage
is released by calling \fBckfree()\fR.

.SH KEYWORDS
command, result, return value, interpreter
