.TH FILESCAN TCL "" "TCL - Tool Command Language"
.ad b
.SH NAME
create_scancontext, delete_scancontext, match, match_default, 
select_scancontext, scan_file - TCL file scanning commands.
.SH SYNOPSIS
.B create_scancontext
.br
.B current_scancontext
.br
.B delete_scancontext \fIscancontext\fR
.br
.B match \fIpattern\fR [\fInocase\fR] \fIcommand\fR
.br
.B match_default \fIcommand\fR
.br
.B scan_continue
.br
.B scan_file \fIfilehandle\fR [\fIscancontext\fR]
.br
.B select_scancontext \fIscancontext\fR
.br
.SH DESCRIPTION
.PP
'@help: filescan/create_scancontext
.B create_scancontext
.br
Create a scan context, match statements defined after \fBcreate_scancontext\fR
will be defined for that scan context until another \fBcreate_scancontext\fR
or \fBselect_scancontext\fR is performed, then new match statements go into
that scan context.  The context identified by "context0" is precreated as a
default context.
'@endhelp
.PP
'@help: filescan/current_scancontext
.B current_scancontext
.br
Return the name of the current scan context.  Useful for grabbing the
current one if you want to
restore it after changing it for some purpose.
'@endhelp
.PP
'@help: filescan/delete_scancontext
.B delete_scancontext \fIscancontext\fR
.br
Delete the scan context identified by \fIscancontext\fR and free all the match
statements and compiled regular expressions associated with the specified
scan context.
'@endhelp
.PP
'@help: filescan/match
.B match \fIpattern\fR [\fInocase\fR] \fIcommand\fR
.br
Specify a TCL \fIcommand\fR, to be evaluated when \fIpattern\fR is matched by
a \fBscan_file\fR command.  The match is added to the current scan context.
Several match statements may be specified for a give context.  \fIPattern\fR
is a regular expression (see the regexp command).  If \fBnocase\fR is
specified, the pattern is matched regardless of alphabetic case.
.P
The global
array, \fBmatchInfo\fR, is available and contains information about the
file being scanned.  The text of the line the file that was matched is in
\fBmatchInfo(line)\fR.  The byte offset into the file of the line that was
matched is in \fBmatchInfo(offset)\fR.  The line number of the line that was
matched is in \fBmatchInfo(linenum)\fR. This is relative to the first line
scanned, not the first line of the file.  The first line is number one.  The
file handle of the file being scanned is in \fBmatchInfo(handle)\fR.  
.P
All
\fBmatch\fR patterns that match a line will be processed in the order that the
specifications where added to the scan context.  The remainder of the
\fBmatch\fR pattern-command pairs may be skipped for a file line if a
\fBcontinue\fR is executed in the match command.  If a return is executed in
the body of the match command, the \fBscan_file\fR command in progress returns
with the value passed to return as it's value.
'@endhelp
.PP
'@help: filescan/match_default
.B match_default \fIcommand\fR
.br
Specify a TCL command, \fIcommand\fR, to be evaluated when the line wasn't
matched by any other match statement during a \fBscan_file\fR. The global
variable \fBmatchInfo\fR is available as described for the \fBmatch\fR command.
'@endhelp
.PP
'@help: filescan/select_scancontext
.B select_scancontext \fIscancontext\fR
.br
Select a scan context context as the current context. \fIScancontext\fR can be
"context0" or one returned by \fBcreate_scancontext\fR.
'@endhelp
.PP
'@help: filescan/scan_file
.B scan_file \fIfilehandle\fR [\fIscancontext\fR]
.br
Scan the file specified by \fIfilehandle\fR (see unixio(TCL)), starting at the
current file pointer. Check all patterns in the current scan context against
it, executing the match commands corresponding to patterns matched.  If
\fIscancontext\fR is specified, use that context, otherwise use the current
context. If you wish to call \fBscan_file\fR within a match command body and a
different scan context, you must specify the scan context in the
\fBscan_file\fI command rather than using \fBselect_scancontext\fR.
'@endhelp
.SH INITIALIZATION
To initialize all the file scanning TCL commands in a custom TCL environment
call:
.sp
.nf
.ft CW
    void TCL_InitFilescan (interp)
           Tcl_Interp *interp;
.ft R
.fi


