.TH IOCMDS TCL "" "TCL - Tool Command Language"
.ad b
.SH NAME
open, close, flush, gets, puts, seek, tell, eof,
copy_open_files, read, bsearch - TCL file I/O commands.
.SH SYNOPSIS
.B open \fIfilename access\fR
.br
.B dup \fIfilehandle\fR
.br
.B dup2 \fIoldhandle newhandle\fR
.br
.B pipe [\fIhandle_var_r handle_var_w\fR]
.br
.B close \fR[\fIfilehandle1...filehandleN\fR]
.br
.B flush \fR[\fIfilehandle1...filehandleN\fR]
.br
.B gets \fIfilehandle\fR [\fIvar\fR]
.br
.B puts \fIfilehandle text\fR [\fBno_nl\fR]
.br
.B seek \fIfilehandle location\fR [\fIorigin\fR]
.br
.B tell \fIfilehandle\fR
.br
.B eof \fIfilehandle\fR
.br
.B copy_open_files \fIhandle1 handle2\fR
.br
.B read \fIhandle\fR [\fIlength\fR]
.br
.B bsearch \fIfilehandle key\fR
.br
.SH DESCRIPTION
.PP
'@help: iocmds/open
.B open \fIfilename access\fR
.br
Open \fIfilename\fR and return a filehandle, \fIaccess\fR can be a combination
of characters from "rwa+" (see fopen).  If the first character of the filename
is a vertical bar ('|'), then filename is command to pipe to or from.  If
access is 'w' it's a pipe to the command, or if it's 'r', it's a pipe from the
command.  The file handles 'stdin', 'stdout' and 'stderr' are preopened at
startup.
'@endhelp
.PP
'@help: iocmds/dup
.B dup \fIfilehandle\fR
.br
Duplicate an open file.  A file handle is created that addresses the
same file as \fIfilehandle\fR.
'@endhelp
.PP
'@help: iocmds/dup2
.B dup2 \fIoldhandle newhandle\fR
.br
Duplicate an open file, specified by \fIoldhandle\fR to a specified handle,
\fInewhandle\fR.  If \fInewhandle\fR is already open, it will be closed.
This is most commonly used for changing the files associated with 
\fIstdin\fR and \fIstdout\fR before a \fBfork\fR.
'@endhelp
.PP
'@help: iocmds/pipe
.B pipe [\fIhandle_var_r handle_var_w\fR]
.br
Create a pipe (see pipe(S)).  If \fIhandle_var_r\fR and \fIhandle_var_r\fR are
specified, then variable \fIhandle_var_r\fR will contain the handle opened for
reading and \fIhandle_var_w\fR will contain the handle opened for writing.  If
the variables are not specified, then a list containing the read followed by
the write handle is returned as the result of the command.
'@endhelp
.PP
'@help: iocmds/close
.B close [\fIfilehandle1...filehandleN\fR]
.br
Close one or more filehandles returned by open.  If no handles are specified,
all open files are closed.
'@endhelp
.PP
'@help: iocmds/flush
.B flush \fR[\fIfilehandle1...filehandleN\fR]
.br
Causes any buffered data for the streams to be written to the file.
'@endhelp
.PP
'@help: iocmds/gets
.B gets \fIfilehandle\fR [\fIvar\fR]
.br
If \fIvar\fR is specified, read a line from \fIfilehandle\fRinto \fIvar\fR and
return the number of characters read, or -1 if EOF. If \fIvar\fR is not
specified, return the line and use \fBeof\fR to determine the file status.
'@endhelp
.PP
'@help: iocmds/puts
.B puts \fIfilehandle text\fR [\fBno_nl\fR]
.br
Write a string, \fItext\fR to the file specified by \fIfilehandle\fR.
A new line will be written following \fItext\fR unless \fBno_nl\fR is 
specified.
'@endhelp
.PP
'@help: iocmds/seek
.B seek \fIfilehandle location\fR [\fIorigin\fR]
.br
Move the file pointer in \fIfilehandle.\fR If \fIorigin\fR is \fBstart\fR or
not specified, seek file to specified \fIlocation\fR from the beginning of the
file.  If \fIorigin\fR is \fBcur\fR, \fIlocation\fR is relative to the file
pointer's current position. If \fIorigin\fR is \fBend\fR, it is relative to
the end of the file.
'@endhelp
.PP
'@help: iocmds/tell
.B tell \fIfilehandle\fR
.br
Return the current location of the file pointer for the specified
\fIfilehandle\fR.
'@endhelp
.PP
'@help: iocmds/eof
.B eof \fIfilehandle\fR
.br                     
Returns a 1 if \fIfilehandle\fR is at EOF, else it returns a zero.
'@endhelp
.PP
'@help: iocmds/copy_open_files
.B copy_open_files \fIhandle1 handle2\fR
.br
Copies the rest of file specified by \fIhandle1\fR from its current position
to the file specified by \fIhandle2\fR.
'@endhelp
.PP      
'@help: iocmds/read
.B read \fIhandle\fR [\fIlength\fR]
.br
Return \fIlength\fR characters from the file specified by \fIhandle\fR.  There
should not be any nulls in the file.  There is no corresponding write because
puts can do the same thing a write would do.  If \fIlength\fR is not
specified, read to the end of file.
'@endhelp
.PP      
'@help: iocmds/bsearch
.B bsearch \fIfilehandle key\fR
.br
Search an opened ASCII-sorted data file, \fIfilehandle\fR, for a line
beginning with \fIkey\fR.  If \fIkey\fR is not found, an empty string is 
returned.
'@endhelp
.SH INITIALIZATION
.PP
To initialize all the Unix I/O TCL character commands in a custom TCL 
environment call:
.sp
.nf
.ft CW
    void TCL_InitIoCmds (interp)
           Tcl_Interp *interp;
.ft R
.fi
.PP      
To initialize the bsearch command in a custom TCL environment call:
.sp
.nf
.ft CW
    void TCL_InitBsearch (interp)
           Tcl_Interp *interp;
.ft R
.fi
      

