/* 
 * Copyright 1990 Karl Lehenbauer, Mark Diekhans, 
 *                Peter da Silva and Jordan Henderson.
 *
 * Permission to use, copy, modify, and distribute this
 * software and its documentation for any purpose and without
 * fee is hereby granted, provided that the above copyright
 * notice appear in all copies.  Karl Lehenbauer, Mark Diekhans,
 * Peter da Silva and Jordan Henderson make no representations
 * about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 */

/*
 * this bsearch routine based on
 *      getpath.c from smail 2.5 (9/15/87)
 */

#ifndef NOSCCSID
        static char *sccs_id = "%M% %I% %H%";
#endif

/* 

        karl                            Thu Sep 27 17:17:53 CDT 1990

        changed max bsearch could return to 1024 from TCL_RESULT_SIZE,
        this should be updated under 3.3 to use the string growing
        routine

*/

#include <stdio.h>
#include <sys/types.h>
#include <ctype.h>

#include "tcl.h"
#include "iocmds.h"

#if defined(SYSV_3_2_0) || defined(XENIX) || defined(BSD)
/* offset seek define, present in sysv 3.2.2 */
#define SEEK_SET 0
#endif

#define MAX_REC_SIZE 1024
extern struct handle handles[MAXFILES];

/*
 *----------------------------------------------------------------------
 *
 * bsearch --
 *      Binary search a sorted ASCII file.
 *
 * Results:
 *      1 - If the key was found.
 *      0 - If it was not found.
 *     -1 - If there was an I/O error.
 *
 *----------------------------------------------------------------------
 */
static int
bsearch (file, key, line)
    FILE *file;
    char *key;          /* what we are looking for */
    char *line;         /* space to store the line */
{
        long pos, middle, hi, lo;
        long filelength = 0;
        long recstart;
        register char *s;
        int c, len;
        int flag;

        if (fseek(file, 0L, 2) != 0)    /* find length */
                return -1;  /* Error */
        filelength = ftell(file);

        lo = 0;
        hi = filelength;
        (void) strcpy( line, key );
/*
** "Binary search routines are never written right the first time around."
** - Robert G. Sheldon.
*/
        for( ;; ) {
                pos = middle = ( hi+lo+1 )/2;
                if (fseek(file, pos, 0) != 0)   /* find midpoint */
                        return -1;  /* Error */
                if(pos != 0)
                        while(((c = getc(file)) != EOF) && (c != '\n'))
                                ;       /* go to beginning of next line */
                if(c == EOF) {
                        *line = '\0';
                        if ferror (file)
                                return -1;
                        else
                                return  0;  /* Not found */
                }
                recstart = ftell (file);
                for( flag = 0, s = line; flag == 0; s++ ) { /* match??? */
                        if( *s == '\0' ) {
                                goto solved;
                        }
                        if((c = getc(file)) == EOF) {
                                *line = '\0';
                                if ferror (file)
                                        return -1;
                                else
                                        return  0;  /* Not found */
                        }
                        flag = c - *s;
                } 
                if(lo >= middle) {              /* failure? */
                        *line = '\0';
                        return(0);
                }
                if((c != EOF) && (flag < 0)) {  /* close window */
                        lo = middle;
                } else {
                        hi = middle - 1;
                }
        }
/* 
** Now just copy the result.
*/
solved:
        if (fseek (file, recstart, SEEK_SET) != 0)
                return -1;
        if (fgets (line, MAX_REC_SIZE-1, file) == NULL)
                return -1;
        len = strlen (line);
        line [len-1] = '\0';  /* Nuke new-line */
        return 1;
}

/*
 *----------------------------------------------------------------------
 *
 * CmdBsearch --
 *     Implements the TCL bsearch command:
 *        bsearch filehandle key
 *     See the iocmds(TCL) manual page.
 *
 * Results:
 *      Standard TCL results.
 *
 *----------------------------------------------------------------------
 */
int
CmdBsearch (clientData, interp, argc, argv)
    char       *clientData;
    Tcl_Interp *interp;
    int         argc;
    char      **argv;
{
        FILE *file;
        int filenumber;
        char s[MAX_REC_SIZE];

        if (argc != 3)
                return Tcl_RetError (interp, "TCL", 
                                     "bad # arg: %.50s handle key", argv[0]);

        if (convfile(interp, argv[0], argv[1], &filenumber, 1) != TCL_OK)
                return TCL_ERROR;

        file = handles[filenumber].fp;
        if (bsearch (file, argv[2], s) < 0)
                return Tcl_RetSysError (interp, (char *)NULL);
        Tcl_Return (interp, s, TCL_VOLATILE);
        return TCL_OK;
}

/*
 *----------------------------------------------------------------------
 *
 * Tcl_Init --
 *      Initialize file I/O commands and install them into Tcl
 *
 * Side effects:
 *      The Unix I/O commands are installed into the specified
 *      interpreter.
 *
 *----------------------------------------------------------------------
 */
Tcl_InitBsearch (interp)
    Tcl_Interp *interp;
{
Tcl_CreateCommand (interp, "bsearch", CmdBsearch, (ClientData)NULL,
                  (void (*)())NULL);
}

