.TH STARTUP TCL "" "TCL - Tool Command Language"
.ad b
.PP
.SH AN INSIDE LOOK AT TCL STARTUP
This document details the ins and outs of the implementation of command line 
processing in Tcl.  You don't need to read this to program and use Tcl, but
it should be of use to people interested in creating Tcl-based tools with
different command line interfaces and others interested in learning the
inner workings of the language and environment.
.PP
Tcl command line processing is partially handled in the C main routine in
\fBtclsh/src\fR, but most of it is handled by Tcl code from the
\fBTclInit.tcl\fR file.
.PP
Upon startup of Tcl, the C main routine creates a Tcl interpreter and then 
has a first crack at the command line:
.PP
All of the arguments in the argv of the main function are merged into a Tcl
list and a Tcl global variable, \fBargv\fR, is set to contain the list.
Note that
at this point the name the program was 
invoked as (\fBargv[0]\fR in the C main) is
the first argument.
.PP
The C main routine then calls \fITcl_Startup\fR, which feeds some startup
commands to the just-created Tcl interpreter.  A Tcl proc named
\fISet_default\fR is created; it works like \fIset\fR except that if
an environment variable exists of the same name as the variable being
defined, its value is used instead of the normal third assignment argument.
.PP
The initial startup code interpreted by Tcl first checks to see if there
is an environment variable named \fBTCLDEFAULT\fR concatenated with
the version number, as in \fBTCLDEFAULT3.12\fR.  If that environment
variable doesn't exist, \fBTCLDEFAULT\fR is checked for.
.PP
If either of the aforementioned environment variables are found, the Tcl
variable \fBTCLDEFAULT\fR is set to the value found, then its first
character is examined.  If the first character is a tilde ("~") or a
slash ("/"), it is taken as the name of the Tcl default file (a file
that contains a Tcl search path, defines an init file, etc.), and that
file is read into Tcl via the \fIsource\fR command.
.PP
If the \fBTCLDEFAULT\fR variable was created but the first character
wasn't a slash or tilde, its contents are evaluated with \fIeval\fR.
.PP
If neither of the \fBTCLDEFAULT\fR environment variables exists, the 
default file named from the \fBConfigure\fR script, returned by
the Tcl command \fB[custom_info defaultfile]\fR, is checked for.
First the startup code looks for the specified file concatenated with
the version number, as in \fB/etc/default/tcl3.12\fR.  If not found,
it checks for the file without the version number.  (This will help
if you have two versions of Tcl at some point -- you may want to use
the new one for new development, but take your time converting old
code, if conversion is necessary.)
.PP
The default file or environment variable is currently expected to
do two things:  It is expected to set the \fBTCLINIT\fR and the
\fBTCLPATH\fR variables.  \fBTCLINIT\fR is the absolute pathname to the
Tcl initialization file; \fBTCLPATH\fR contains one or more colon-separated
pathnames to your Tcl source files, in the same manner as the \fBPATH\fR
environment variable points to your search path.
The init file is usually called \fBTclInit.tcl\fR, and it is now loaded
into Tcl via the \fIsource\fR command.
.PP
Now, assuming that the standard \fBTclInit.tcl\fR is being used, the init 
file does the following things...
.PP
The \fIempty\fR procedure is defined.  It returns 
\fB1\fR if the argument is an
empty list, otherwise \fB0\fR.
.PP
The Tcl init file defines the \fIautoload\fR procedure.  Then it defines
the \fIpackage\fR and \fIdefpackage\fR package-handling procedures.
See the manpage on autoloads and packages for details.
.PP
Next \fIload_package_indexes\fR is defined.  \fILoad_package_indexes\fR
searches along the Tcl
path and loads in the \fB.tndx\fR files corresponding to all of the
\fB.tlib\fR files it finds.  If a \fB.tndx\fR file is out of date, is
is regenerated from the \fB.tlib\fR file if possible.
.PP
Next \fBTclInit.tcl\fR defines a Tcl
searchpath variable, called \fBTCL_PATHLIST\fR, as a list of all of the
colon-separated files set by the optional \fBTCLPATH\fR environment variable
or by the default file.
.PP
Then \fIsearchpath\fR is defined -- it searches along a path for a specified
file and returns the path including the file if found.
The \fIload\fR procedure is also defined.  It works like \fIsource\fR, except 
it uses \fIsearchpath\fR to check along the entire \fBTCL_PATHLIST\fR.
.PP
Next, \fBTclInit.tcl\fR sets the global variable
\fBprogramName\fR to contain the name
Tcl was invoked as, and removes it from the argv list (it was the first
entry in the list).  If Tcl was invoked as \fBtcl\fR and there
are no other command-line arguments, the user is given an interactive 
session by setting the \fBinteractiveSession\fR variable to 1
and returning.
.PP
If there are other command line arguments and the first one is \fB-f\fR,
then if there is at least one following argument, both are removed
from the argv list and a \fIsource\fR is done on the argument that
followed the \fB-f\fR.  This is like \fIawk(1)\fR, so you can 
say \fBtcl -f sourcefile\fR
to load and execute \fBsourcefile\fR.
.PP
If the first argument is 
not \fB-f\fR, it is removed from the argv list and
evaluated by Tcl.  This is like awk, too -- the program is the first
argument on the command line if there are command line arguments and
the first one is not \fB-f\fI.
.PP
If tcl was not invoked as \fBtcl\fR or \fBxtcl\fR, but as some other name,
for example, by invoking tcl through a link to tcl named \fBfoo\fR,
\fBTclInit.tcl\fR searches along the \fBTCL_PATHLIST\fR looking for a
file named
\fBfoo.tcl\fR and, if it finds it, it does a \fIsource\fR command on it.
It if is not found, an exit with status 2 is taken.
.PP
If a TCL error occurs during the execution of the program specified
on the command line or through a file with the \fB-f\fR option, an
exit with status 1 is taken.  If a UNIX error occurs, an exit 2 is
taken.  Look at the Tcl error handling docs for more info on TCL
and UNIX error types.
.PP
After all this, if it is not an interactive
invocation, \fBTclInit.tcl\fR returns.
.PP
If Tcl was invoked interactively, a "Welcome to Tcl" message is output.
.PP
Next the \fItoplevel\fR and
\fIdownlevel\fR prompt hooks are defined.  By
default these are \fBtcl>\fR and \fB=>\fR.  These hooks are evaluated
by the command loop.  Whatever is returned by the execution of
the contents of the \fBtoplevel_prompt_hook\fR variable is used as the
toplevel prompt, and whenever the commandloop wants to issue a
prompt but the user is not at the top-level, i.e. they are nested
one or more levels deep within open curly brackets, the
\fBdownlevel_prompt_hook\fR variable is executed and the value returned
is issued as a prompt.
.PP
Next the \fIexecute_shell_command\FR procedure is defined.  It is
used by the invalid command hook routine if an request command
name cannot be found while executing at the top level, the hook
routine searches the search path to see if the requested name exists
out along it, and if so a proc is created of that name which calls
\fIexecute_shell_command\fR with the relevant information, so that
when the hook routine occurs, if the name was found along the path,
a proc will have been defined that can execute that command, and
it stays around as a cache to improve performance should the command
be executed subsequently during that run.
.PP
The \fIdemand_load\fR procedure is defined.  It takes on argument,
the name of a procedure that is connected with an autoload file
or a package index file.  If it is not known and the package indexes
have not been loaded, \fIdemand_load\fR will load them and look
check one more time to see if the procedure is now known.  If so,
it is loaded.  Note that this index-loading operation only occurs
once per run.
.PP
Finally, the invalid command procedure is defined and the 
\fBinvalid_command_name_hook\fR variable is set to that name.  When
Tcl can't find a command or procedure of a given name to execute
and the \fBinvalid_command_name_hook\fR variable is not empty,
instead of just giving up and returning an error, Tcl first 
executes the invalid command name hook with an argument containing
the name of the function it couldn't find.  When the
invalid command name hook function returns, Tcl will check once more
to see if the command it couldn't previously find is now present.
If it is there, Tcl proceeds, executing the command on as if nothing
special had happened.  If it is not present, an
error is returned.  This gives a sort of "virtual memory" capability
for procedures, and greatly facilitated the writing autoloads and
packages.
.PP
At last, The \fBTclInit.tcl\fR checks the user's home directory (as indicated 
by the \fBHOME\fR environment variable) to see if a file 
named \fB .tclrc\fR is found and,
if so, a \fIsource\fR is done on it.  This allows users to automatically
set up their specific environment and load up their extensions when
using Tcl interactively.  
.PP
Note that a .tclrc file is not checked for if Tcl is not being
run interactively.  We felt that it was undesirable to do this because
programmers would end up creating ostensibly standalone Tcl programs
that were, in fact, dependent on something in the programmer's .tclrc
and hence wouldn't run for anybody else.  This is, of course, still
a possibility for any Tcl programs that a programmer-with-a-.tclrc-file
only runs interactively.
.PP
Finally, the end of the Tcl init file is reached or a return is performed
somewhere earlier within it (at the top level), the \fITcl_Eval\fR call
that the C main routine performed to do the \fIsource\fR command on 
\fBTclInit.tcl\fR returns, and the C main does a few more things...
.PP
First, it checks to see if executing \fBTclInit.tcl\fR returned an error, and
if so, prints the error info and "Tcl initialization failed!" and exits
with error status 5.
.PP
Next, the C main checks the Tcl global variable \fBinteractiveSession\fR.
This variable should have been set by \fBTclInit.tcl\fR, to
\fB0\fR if the session
is not interactive, and \fB1\fR if it is.
.PP
If the \fBinteractiveSession\fR variable does not contain a \fB0\fR, the
C main starts up an interactive command loop.
.PP
Finally (after the user exits the interactive command loop, if Tcl was
invoked in a manner such that one was executed), the C main deletes the
Tcl interpreter data structures and exits with an exit status of 0.
