#
# build a fullname database by cracking the names in the password file
#
# This is used smail 2.5 to lookup full names in the database.
#
# For example, user "keegan", fullname "Calvin Wilson Keegan" writes
# the following records into the fullname database:
#
# Calvin.Wilson.Keegan	keegan
# Calvin.W.Keegan keegan
# Calvin.Keegan keegan
#
# Then Calvin can receive mail by fullname as Calvin.Keegan@sugar.hackercorp.com
#
#  field 0 of the password file is name, field 2 is user number, field 4 is 
#   full name
#
#  an associative array is used to keep from producing a lot of
#   duplicate entries if one user has many logins with the same
#   full name

global outfp

proc middlename {name} {
	set result {{}}

	set name [index [split . $name] 0]
	if {[length $name chars] > 1} {
		set result [concat $result [index $name 0 chars]]
	}
	if {[length $name chars] != 0} {
		set result [concat $result $name]
	}
	return $result
}

proc fullname {username fullname} {
	global outfp fullname_array

	if ![info exists fullname_array($fullname)] {
	
		set fullname_array($fullname) $username
		if {[length $fullname] != 3} {
			puts $outfp [format "%s\t%s" [join . $fullname] $username]
		} else {
			foreach i [middlename [index $fullname 1]] {
				puts $outfp [format "%s\t%s" [join . [concat [index $fullname 0] $i [index $fullname 2]]] $username]
			}
		}
	}
}

proc build_fullname_database {} {
	global outfp
	global fullname_array
	
	set fh [open /etc/passwd r]
	set outfp [open "|sort" w]

	while {[gets $fh rawline]} {
		set line [split : $rawline]
		if {[index $line 2] >= 100} {
			fullname [index $line 0] [index $line 4]
		}
	}
	close $fh
}

build_fullname_database
